#!/usr/bin/sh
#copyright	"%c%"
#ident	"@(#)opensrc:src/espgs/espgs.sh /main/uw714mp/6"

#
# dist/		espgs-7.07.1 distribution from http://www.cups.org/
# patches/*	Patches to be applied.
# espgs.sh	Build script (this file).
# espgs.depend	Depend file for top-level build script.
# espgs.docview	Docview glue.
#
# fonts/	Font files from gnu-gs-fonts-[std,other]-6.0 distribution.
#

set -x
set -e

#
# Apply patches.
#
cd dist
for patch in \
	7.07.1-port \
	7.07.1-ijs \
	7.07.1-fz533156
do
	[ -f ../patches/${patch}.applied ] || {
		/bin/patch -c -p1 -i ../patches/${patch}.patch
		/bin/date > ../patches/${patch}.applied
	}
done

#
# Create link to jpeg source.
# We want to compile it with non-standard flags to support old PS files.
#
JPEG_DIR=$ROOT/src/jpeg/dist
if [ ! -d $JPEG_DIR ]
then
	echo "ERROR: $JPEG_DIR not found" >&2
	exit 1
fi
rm -f ./jpeg
ln -s $JPEG_DIR ./jpeg

#
# Tell configure to use cups-config from the cups src directory.
#
ac_cv_path_CUPSCONFIG=$ROOT/src/cups/dist/cups-config
export ac_cv_path_CUPSCONFIG

./configure \
	--host=i386-sco-sysvUnixWare7.1.4 \
	--build=i386-sco-sysvUnixWare7.1.4 \
	--prefix=/usr \
	--with-fontpath=/usr/share/cups/fonts \
	--with-ijs \
	--without-gimp-print \
	--without-omni \
	--with-x \
	--x-includes=$TOOLS/usr/X11R6.1/include \
	--x-libraries=$TOOLS/usr/X11R6.1/lib

#
# The configure script does not properly update the following variables in
# Makefile.
#
# EXTRALIBS.
# + link libcups and libcupsimage statically so that gs is independent of cups.
#   (had to undo for this version of espgs to work with cups 1.3.3 port)
#
# XLIBS
# + add libSM and libICE. (Note -l is added by Makefile.)
#
# Build and install in two steps.  This is to avoid getting the install path
# (with $ROOT/$MACH) hardcoded into the gs binary.
#
$MAKE \
	AR="$AR" \
	ARFLAGS="$ARFLAGS" \
	EXTRALIBS="-Bdynamic -lcupsimage -lcups -Bdynamic -lsocket -lnsl -lthread" \
	XLIBS="Xt SM ICE Xext X11" \
	man1ext=".1"

#
# Now install.
#
# Define install_prefix and cups_config
# + cups.mak uses them while installing files.
#
	ARFLAGS="$ARFLAGS" \
$MAKE \
	AR="$AR" \
	EXTRALIBS="-Bdynamic -lcupsimage -lcups -Bdynamic -lsocket -lnsl" \
	XLIBS="Xt SM ICE Xext X11" \
	man1ext=".1" \
	prefix=$ROOT/$MACH/usr \
	datadir=$ROOT/$MACH/usr/share \
	install_prefix=$ROOT/$MACH \
	cups_config=$ac_cv_path_CUPSCONFIG \
	install

#
# Ghostscript (by default) does not build the IJS library.  We need it for
# hpijs.
#
cd ijs
./configure \
	--host=i386-sco-sysvUnixWare7.1.4 \
	--build=i386-sco-sysvUnixWare7.1.4 \
	--prefix=/usr

#
# The configure script does not update the following variables in the
# ijs/Makefile.
#
$MAKE \
	CFLAGS="$CFLAGS -Kthread" \
	AR="$AR" \
	ARFLAGS="$ARFLAGS" \
	prefix=$ROOT/$MACH/usr \
	install-header \
	install-lib

# Now install in cross environment.
$MAKE \
	CFLAGS="$CFLAGS -Kthread" \
	AR="$AR" \
	ARFLAGS="$ARFLAGS" \
	prefix=$TOOLS/usr \
	install-header \
	install-lib

#
# Install license file.
#
cd ..
$INSTALL -d $ROOT/$MACH/usr/share/ghostscript
$INSTALL -m 0444 LICENSE $ROOT/$MACH/usr/share/ghostscript

#
# Install Docview metadata file.
#
cd ..
DS_group=/usr/share/meta/doc/HelpTopics/DSKhome/DSKgroup
$INSTALL -d $ROOT/$MACH/$DS_group
$INSTALL -m 0444 espgs.docview $ROOT/$MACH/$DS_group/DSK_gs.desktop

#
# Install GNU Ghostscript 6.0 fonts.  The fonts directory has both
# gnu-gs-fonts-std-6.0 and gnu-gs-fonts-other-6.0 fonts.
#
FONTDIR=/usr/share/ghostscript/fonts
$INSTALL -d $ROOT/$MACH/$FONTDIR
ls fonts | xargs -i $INSTALL -m 0444 fonts/{} $ROOT/$MACH/$FONTDIR

exit 0
